using Nemo, PolyHarmonic


# Examples used in the paper
# case Ia
let
  k = 0; m = 3; d = 2
  f = lconstruction(k,m,d)
  coefficients(f)
  # 85//1296  11//216  1//72
  # 7//16     3//8     1//8
  # 1         1        1//2
  # 0         0        1//2
  fE = eisenstein_spectral_point_expansion(f)
  coefficients(fE)
  # 5//27  1//18  0
  # 5//8   1//4   0
  # 1      1      0
  # 0      0      1//2
end

# Examples used in the paper
# case Ib
let
  k = 0; m = 3; d = 0
  f = lconstruction(k,m,d)
  fP = poincare_spectral_point_expansion(f,-1)
  coefficients(f)
  # 1//36
  # 1//4
  # 1
  # 1
  coefficients(fP)
  # 1//384*pi^-3
  # 1//32*pi^-2
  # 1//4*pi^-1
  # 1

  k = 0; m = 3; d = 2
  f = lconstruction(k,m,d)
  fP = poincare_spectral_point_expansion(f,-1)
  coefficients(f)
  # 85//1296  11//216  1//72
  # 7//16     3//8     1//8
  # 1         1        1//2
  # 0         0        1//2
  coefficients(fP)
  # 0  0  1//768*pi^-3
  # 0  0  1//64*pi^-2
  # 0  0  1//8*pi^-1
  # 0  0  1//2
end

# Examples used in the paper
# case Ic
let
  k = 0; m = 3; d = 0
  f = lconstruction(k,m,d)
  fP = poincare_spectral_point_expansion(f,-1)
  FfP = mirror(raising(fP,1-k))
  coefficients(FfP)
  # -1//24*pi^-1
  # -1//2
  # -4*pi
  # -16*pi^2

  k = 0; m = 3; d = 2
  f = lconstruction(k,m,d)
  fP = poincare_spectral_point_expansion(f,-1)
  FfP = mirror(raising(fP,1-k))
  coefficients(f)
  # 85//1296  11//216  1//72
  # 7//16     3//8     1//8
  # 1         1        1//2
  # 0         0        1//2
  coefficients(FfP)
  # 0  1//24*pi^-1  -1//48*pi^-1
  # 0  1//2         -1//4
  # 0  4*pi         -2*pi
  # 0  16*pi^2      -8*pi^2
end

# Examples used in the paper
# case Id
let
  k = -2; m = 2; d = 2
  f = rconstruction(k,m,d)
  fE = eisenstein_spectral_point_expansion(f)
  2*coefficients(f)
  # 1//2  -3//2  1//2
  # 0     1      -1//2
  # 0     0      1//2
  2*coefficients(fE)
  # 1//2  -3//2  1//2
  # 1     -3     1
  # 1     -3     1
end

# Examples used in the paper
# case IIIa
let
  k = 4; m = 2; d = 2
  f = lconstruction(k,m,d)
  fE = eisenstein_spectral_point_expansion(f)
  coefficients(f)
  # 19//432  -5//72  1//24
  # -1//27   1//9    -1//6
  # 0        0       1//2
  coefficients(fE)
  # 1//72  1//12  0
  # 1//9   -1//3  0
  # 0      0      1//2
end

let
  k = 4; m = 3; d = 2
  f = rconstruction(k,m,d)
  fE = eisenstein_spectral_point_expansion(f)
  coefficients(f)
  # 1//288   37//2160  1//72
  # 1//1440  11//1440  1//96
  # 0        1//720    1//240
  # 0        0         1//1440
  coefficients(fE)
  # 1//288  37//2160  1//72
  # 1//96   37//720   1//24
  # 1//48   37//360   1//12
  # 1//48   37//360   1//12
end

# Examples used in the paper
# case IIIb
let
  k = 2; m = 2; d = 0
  f = rconstruction(k,m,d)
  fE = eisenstein_spectral_point_expansion(f)
  2*coefficients(f)
  # 1
  # 1
  # 1//3
  2*coefficients(fE)
  # 1
  # 2
  # 2
  k = 2; m = 2; d = 2
  f = rconstruction(k,m,d)
  fE = eisenstein_spectral_point_expansion(f)
  2*coefficients(f)
  # 1//6  5//6  1//2
  # 0     1//3  1//2
  # 0     0     1//6
  2*coefficients(fE)
  # 1//6  5//6  1//2
  # 1//3  5//3  1
  # 1//3  5//3  1
end

# Examples used in the paper
# case IIIc
let
  k = 0; m = 3; d = 2
  f = lconstruction(k,m,d)
  fP = poincare_spectral_point_expansion(f,-1)
  RFfP = raising(mirror(raising(fP,1-k)),4)
  coefficients(RFfP)
  # -14752//3*pi^3  7488*pi^3     -1920*pi^3
  # -59008*pi^4     89856*pi^4    -23040*pi^4
  # -472064*pi^5    718848*pi^5   -184320*pi^5
  # -1888256*pi^6   2875392*pi^6  -737280*pi^6
end

# Examples used in the paper
# case IIId
let
  k = 0; m = 3; d = 2
  f = lconstruction(k,m,d)
  fP = poincare_spectral_point_expansion(f,-1)
  RfP = raising(fP,4)
  coefficients(RfP)
  # 70//3*pi   -100//3*pi   8*pi
  # 280*pi^2   -400*pi^2    96*pi^2
  # 2240*pi^3  -3200*pi^3   768*pi^3
  # 8960*pi^4  -12800*pi^4  3072*pi^4
end
