struct DeltaSpectralFamily
  LR :: Symbol
  k :: Int
  m :: Int
  A :: Matrix{fmpq}
  B :: Matrix{fmpq}
  C :: Matrix{fmpq}
  Apsdinv :: Matrix{fmpq} # pseudo right inverse
end

# Representation of a linear combination 
#   𝔢_{r,m-r} \rmL^{m-r} f^{(d)} (L-construction) or
#   𝔢_{r,m-r} \rmR^r f^{(d)}     (R-construction).
# Whether it represents an L or R construction is stored in delta.
struct LRConstrLRExpansion
  delta :: DeltaSpectralFamily
  # L-construction: coefficients of 𝔢_{r,m-r} \rmL^{m-r} f^{(d)}
  # R-construction: coefficients of 𝔢_{r,m-r} \rmR^r f^{(d)}
  coeffs :: Matrix{fmpq}
end

# Representation of a linear combination 
#   𝔢_{r,m-r} f^{(d)}_{m-r-l+s0} (L-construction),
#             [of wt k - 2m + 2r + 2l]
#   𝔢_{r,m-r} f^{(d)}_{-r-l+s0}  (R-construction),
#             [of wt k + 2r + 2l]
# where l is the weight shift and s0 is the spectral shift
# The sign of spectral shift under Maaß operators is
#   L f_s -> f_{s+1}  and  R f_s -> f_{s-1}
# The mirror family of f_{k,s} is msgn msc^-k f_{-k,s+k}, where msc is the
# mirrow scale and msgn is the mirrow sign.
struct LRConstrSpectralPointExpansion
  base_ring :: Ring
  poly_ring :: PolyRing
  LR :: Symbol
  k :: Int 
  # the weight shift by applying additional Maaß operators
  weight_shift :: Int
  # the spectral shift by applying the mirror operator
  spectral_shift :: Int
  # polynomial in one variable (namely s) over the base ring with
  #   L^r f_{k,s} = lpoly(k,r)(s) f_{k-2r,s+r}
  #   R^r f_{k,s} = rpoly(k,r)(s) f_{k+2r,s-r}
  lpoly :: Function
  rpoly :: Function
  mirror_scale :: RingElem
  mirror_sign :: Int
  # L-construction: coefficients of 𝔢_{r,m-r} f^{(d)}_{m-r-kLR}
  # R-construction: coefficients of 𝔢_{r,m-r} f^{(d)}_{-r+kLR}
  coeffs :: Matrix{RingElem}
end
