function runtest_lrconstruction()
  delta = PolyHarmonic.delta
  apply_delta = PolyHarmonic.apply_delta
  tdtr = PolyHarmonic.tdtr
  coefficients_pullback = PolyHarmonic.coefficients_pullback

  @testset "L and R construction" begin
  
    # This tests the construction of f_L = f_L^{(0)}.
    @testset "fL depth 0, k=$k, m=$m" for k in -5:5, m in 0:5
      # Test that fL0 vanishes under Delta
      f = lconstruction(k,m,0)
      @test !iszero(f)
      @test iszero(apply_delta(f))
    end;
    
    # This tests three details from the proof of the main theorem.
    @testset "fL proof, k=$k, m=$m" for k in -5:5, m in 1:5
      k <= 0 || k > m || continue
      # Test that fL0 vanishes under Delta
      f = lconstruction(k,m,0)
      cs = coefficients_pullback(f)
      @test !iszero(cs[end,1])
      @test cs[end-1,1]*(1-k) == cs[end,1]
      k <= 0 || k > m+1 || continue
      f = lconstruction(k,m,1)
      cs = coefficients_pullback(f)
      @test delta(f).A*cs[:,2] == (m+1-k)*cs[:,1] - delta(f).B*cs[:,1]
    end;
    
    # This tests the the main theorem for f_L^{(d)}.
    @testset "fL general depth, k=$k, m=$m" for k in -5:5, m in 1:5
      k <= 0 || k > m+1 || continue
      @testset "d = $d" for d in 1:5
        # Test that fL0 vanishes under Delta
        f = lconstruction(k,m,d)
        for t in 1:d  f = apply_delta(f)  end
        @test !iszero(f)
        @test iszero(apply_delta(f))
      end
    end;
    
    # This tests the construction of f_L = f_L^{(0)}.
    @testset "fR depth 0, k=$k, m=$m" for k in -5:5, m in 0:5
      # Test that fR0 vanishes under Delta
      f = rconstruction(k,m,0)
      @test !iszero(f)
      @test iszero(apply_delta(f))
    end;
  
    # This tests three details from the proof of the main theorem.
    @testset "fR proof, k=$k, m=$m" for k in -5:5, m in 1:5
      k > 0 || k <= -m || continue
      # Test that fL0 vanishes under Delta
      f = rconstruction(k,m,0)
      cs = coefficients_pullback(f)
      @test !iszero(cs[1,1])
      @test k*cs[2,1] == m*cs[1,1]
      k > 1 || k <= -m || continue
      f = rconstruction(k,m,1)
      cs = coefficients_pullback(f)
      @test ( delta(f).A*cs[:,2]
              == (1-k)*cs[1,1]//tdtr(cs[:,1]) .* cs[:,1] - delta(f).B*cs[:,1] )
    end;
    
    # This tests the the main theorem for f_R^{(d)}.
    @testset "fR general depth, k=$k, m=$m" for k in -5:5, m in 1:5
      k > 1 || k <= -m || continue
      @testset "d = $d" for d in 1:5
        # Test that fR0 vanishes under Delta
        f = rconstruction(k,m,d)
        for t in 1:d  f = apply_delta(f)  end
        @test !iszero(f)
        @test iszero(apply_delta(f))
      end
    end;
  
  end
end
