function runtest_spectral_point_expansion()
  @testset "expansion at spectral points" begin
    @testset "Δ on L construction of Eisenstein series, k=$k, m=$m, d=$d" for k in -5:5, m in 0:5, d in 0:4
      k <= 0 || k > m+1 || continue
      f = eisenstein_spectral_point_expansion(lconstruction(k,m,d))
      @test !iszero(laplace(f,d))
      @test iszero(laplace(f,d+1))
    end

    @testset "Δ on R construction of Eisenstein series, k=$k, m=$m, d=$d" for k in -5:5, m in 0:5, d in 0:4
      k > 1 || k <= -m || continue
      f = eisenstein_spectral_point_expansion(rconstruction(k,m,d))
      @test !iszero(laplace(f,d))
      @test iszero(laplace(f,d+1))
    end

    @testset "Δ on L construction of Poincaré series, k=$k, m=$m, d=$d" for k in -5:5, m in 0:5, d in 0:4
      k <= 0 || k > m+1 || continue
      n = 2
      f = poincare_spectral_point_expansion(lconstruction(k,m,d),n)
      @test !iszero(laplace(f,d))
      @test iszero(laplace(f,d+1))
    end

    @testset "Δ on R construction of Poincaré series, k=$k, m=$m, d=$d" for k in -5:5, m in 0:5, d in 0:4
      k > 1 || k <= -m || continue
      n = 2
      f = poincare_spectral_point_expansion(rconstruction(k,m,d),n)
      @test !iszero(laplace(f,d))
      @test iszero(laplace(f,d+1))
    end
    
    @testset "mirror on L construction of Eisenstein series, k=$k, m=$m, d=$d" for k in -5:5, m in 0:5, d in 0:4
      k <= 0 || k > m+1 || continue
      f = eisenstein_spectral_point_expansion(lconstruction(k,m,d))
      @test lowering(f) == mirror(raising(mirror(f)))
      @test raising(f) == mirror(lowering(mirror(f)))
    end

    @testset "mirror on R construction of Eisenstein series, k=$k, m=$m, d=$d" for k in -5:5, m in 0:5, d in 0:4
      k > 1 || k <= -m || continue
      f = eisenstein_spectral_point_expansion(rconstruction(k,m,d))
      @test lowering(f) == mirror(raising(mirror(f)))
      @test raising(f) == mirror(lowering(mirror(f)))
    end

    @testset "mirror on L construction of Poincaré series, k=$k, m=$m, d=$d" for k in -5:5, m in 0:5, d in 0:4
      k <= 0 || k > m+1 || continue
      n = 2
      f = poincare_spectral_point_expansion(lconstruction(k,m,d),n)
      @test lowering(f) == mirror(raising(mirror(f)))
      @test raising(f) == mirror(lowering(mirror(f)))
    end

    @testset "mirror on R construction of Poincaré series, k=$k, m=$m, d=$d" for k in -5:5, m in 0:5, d in 0:4
      k > 1 || k <= -m || continue
      n = 2
      f = poincare_spectral_point_expansion(rconstruction(k,m,d),n)
      @test lowering(f) == mirror(raising(mirror(f)))
      @test raising(f) == mirror(lowering(mirror(f)))
    end
  end
end
